<?php

/**
 * Callback function to render Taxamo settings page.
 */
function commerce_taxamo_content_admin_taxamo() {
  $build = array();

  if (!commerce_taxamo_load_taxamo_php()) {
    drupal_set_message(t('Taxamo PHP library not found. Please consult the README.txt for installation instructions.'), 'warning');
    $build['warning'] = array('#markup' => t("Before to set up the module, please consult the README.txt for installation instructions."));
  }
  else {
    $build['commerce_taxamo_settings_form'] = drupal_get_form('commerce_taxamo_settings_form');
  }

  return $build;
}

/**
 * Function to generate the administration settings form for Taxamo.
 */
function commerce_taxamo_settings_form($form, &$form_state) {
  commerce_taxamo_ensure_fields();
  commerce_taxamo_update_taxamo_product_types();

  $form['commerce_taxamo_public_token'] = array(
    '#title' => t('Public token'),
    '#type' => 'textfield',
    '#default_value' => commerce_taxamo_get_var('commerce_taxamo_public_token'),
    '#description' => t("Public token is available from a merchant dashboard, in <strong>Account settings</strong> panel."),
    '#required' => TRUE,
  );

  $form['commerce_taxamo_private_token'] = array(
    '#title' => t('Private token'),
    '#type' => 'textfield',
    '#default_value' => commerce_taxamo_get_var('commerce_taxamo_private_token'),
    '#description' => t("Private token is available from a merchant dashboard, in <strong>Account settings</strong> panel."),
    '#required' => TRUE,
  );

  $form['commerce_taxamo_component_display_title'] = array(
    '#title' => t('Display title'),
    '#type' => 'textfield',
    '#default_value' => commerce_taxamo_get_var('commerce_taxamo_component_display_title'),
    '#description' => t("Text used on checkout for Taxamo calculated tax amount."),
    '#required' => TRUE,
  );

  t(commerce_taxamo_get_var('commerce_taxamo_component_display_title'));

  $form['commerce_taxamo_product_type_default_value'] = array(
    '#title' => t('Default Product Type'),
    '#type' => 'radios',
    '#options' => commerce_taxamo_product_types(),
    '#default_value' => commerce_taxamo_get_var('commerce_taxamo_product_type_default_value'),
    '#description' => t("This value is used on newly created products and products that do not have a Taxamo Product Type selected."),
    '#required' => TRUE,
  );

  $form['commerce_taxamo_tax_included'] = array(
    '#title' => t('Taxes inluded in product prices'),
    '#type' => 'checkbox',
    '#default_value' => commerce_taxamo_get_var('commerce_taxamo_tax_included'),
    '#description' => t("Whether the taxes amount is already included in product prices or not. This is a global option and can not be modified at Product level."),
  );

  $form['commerce_taxamo_error_handling'] = array(
    '#title' => t('Error handling'),
    '#type' => 'radios',
    '#options' => array(
      COMMERCE_TAXAMO_ERROR_BLOCK => t("Block checkout process and show an error message to the user to help him/her fix the issue."),
      COMMERCE_TAXAMO_ERROR_WARNING => t("Show a warning message to the user to help him fix the issue, but let him/her finish the checkout process if he/she doesn't want to fix anything."),
      COMMERCE_TAXAMO_ERROR_CONTINUE => t("Do not show the error message to the user and let him/her finish the checkout process."),
    ),
    '#default_value' => commerce_taxamo_get_var('commerce_taxamo_error_handling'),
    '#description' => t("Sometimes there could be an error when retrieving taxes information from Taxamo. These options let you configure what should happen when an error occurs.<br />It doesn't matter what option you choose, errors are always recorded in Drupal's Watchdog."),
    '#required' => TRUE,
  );

  $form['advanced'] = array(
    '#title' => t("Advanced options"),
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );

  $form['advanced']['contry_detection'] = array(
    '#title' => t("Country detection"),
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );

  $form['advanced']['contry_detection']['commerce_taxamo_country_detection'] = array(
    '#title' => t("Country detection method"),
    '#type' => 'radios',
    '#options' => array(
      COMMERCE_TAXAMO_COUNTRY_TAXAMO => t("Let Taxamo detect it"),
      COMMERCE_TAXAMO_COUNTRY_IP => t("Force it by IP"),
      COMMERCE_TAXAMO_COUNTRY_BILLING => t("Force it by billing address"),
      COMMERCE_TAXAMO_COUNTRY_DEFINED => t("Force it with a specific country")
    ),
    '#default_value' => commerce_taxamo_get_var('commerce_taxamo_country_detection'),
    '#required' => TRUE,
    '#description' => t("Taxes are calculated depending on buyer's country. Different country detection methods could result in different taxes values."),
  );

  $form['advanced']['contry_detection']['commerce_taxamo_country_defined'] = array(
    '#title' => t("Defined country"),
    '#type' => 'textfield',
    '#default_value' => commerce_taxamo_get_var('commerce_taxamo_country_defined'),
    '#states' => array(
      'visible' => array(
        ':input[name="commerce_taxamo_country_detection"]' => array('value' => COMMERCE_TAXAMO_COUNTRY_DEFINED),
      ),
      'required' => array(
        ':input[name="commerce_taxamo_country_detection"]' => array('value' => COMMERCE_TAXAMO_COUNTRY_DEFINED),
      ),
    ),
    '#description' => t("2 letters country code as defined by !link.", array("!link" => l("ISO 3166-2", 'https://en.wikipedia.org/wiki/ISO_3166-2', array('external' => TRUE)))),
  );

  $form['advanced']['statuses'] = array(
    '#title' => t("Order statuses"),
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );

  $form['advanced']['statuses']['commerce_taxamo_order_statuses_delete'] = array(
    '#title' => t("Order statuses to delete Taxamo line item"),
    '#type' => 'select',
    '#options' => commerce_order_status_options_list(),
    '#default_value' => commerce_taxamo_get_var('commerce_taxamo_order_statuses_delete'),
    '#multiple' => TRUE,
    '#description' => t("When the order is in one of the selected statuses, the Taxamo line item will be removed from the order. This is used to do not show outdated Taxes information.<br />It is only removed if the order is not completed."),
  );

  $form['advanced']['statuses']['commerce_taxamo_order_statuses_precalculate'] = array(
    '#title' => t("Order statuses to precalculate taxes using Taxamo"),
    '#type' => 'select',
    '#options' => commerce_order_status_options_list(),
    '#default_value' => commerce_taxamo_get_var('commerce_taxamo_order_statuses_precalculate'),
    '#multiple' => TRUE,
    '#description' => t("Taxes are retrieved from Taxamo only when the order is in one of the selected statuses."),
  );

  $form['advanced']['statuses']['commerce_taxamo_order_statuses_confirm'] = array(
    '#title' => t("Order statuses to confirm taxes calculated by Taxamo"),
    '#type' => 'select',
    '#options' => commerce_order_status_options_list(),
    '#default_value' => commerce_taxamo_get_var('commerce_taxamo_order_statuses_confirm'),
    '#multiple' => TRUE,
    '#description' => t("When the order is in one of the selected statuses, the system will inform Taxamo that the precalculated taxes are confirmed."),
  );

  $form['#validate'][] = 'commerce_taxamo_settings_form_validate';

  return system_settings_form($form);
}

function commerce_taxamo_settings_form_validate(&$form, &$form_state) {
  if ($form_state['values']['commerce_taxamo_country_detection'] == COMMERCE_TAXAMO_COUNTRY_DEFINED && empty($form_state['values']['commerce_taxamo_country_defined'])) {
    form_set_error('commerce_taxamo_country_defined', t("A country must be defined."));
  }
}
